@@ -2,10 +2,10 @@ import numpy
 import xarray
 import matplotlib.pyplot as plt
 
+
 class objearth():
     def __init__(self,DataArray):
         self.DataArray = DataArray
-
     def plotshow(self,lst=True):
         self.lst = lst
         if type(self.DataArray) == xarray.core.dataarray.DataArray:
@@ -51,7 +51,21 @@ class objearth():
         
         else:
             print("Nonetype :",type(self.DataArray))
+            
+    def NDVI(self):
+        red = xarray.where(self.DataArray.red==-9999,numpy.nan,self.DataArray.red)
+        nir = xarray.where(self.DataArray.nir==-9999,numpy.nan,self.DataArray.nir)
+        ndvi1 = (nir-red)/(nir+red).to_numpy()
+        ndvi3 = numpy.clip(ndvi1,-1,1)
+        im_ratio = ndvi3.shape[1]/ndvi3.shape[0]
+        plt.figure(figsize=(8,8))
+        plt.xticks([]), plt.yticks([])
+        plt.imshow(ndvi3,cmap='viridis')
+        plt.clim(-1,1)
+        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
+        plt.show()
+        return ndvi3
+
+   
     
-    def mosaic(self):
-        product = self.DataArray.max(dim="time",skipna=True)
-        return product
+
